#
# spec file for package apr-util
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         apuver 1
%define         libname lib%{name}%{apuver}
%define         dso_libdir %{_libdir}/apr-util-%{apuver}
%define         includedir %{_includedir}/apr-%{apuver}
Name:           apr-util
Version:        1.6.1
Release:        lp150.3.3.1
Summary:        Apache Portable Runtime (APR) Utility Library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Url:            http://apr.apache.org/
Source:         http://www.apache.org/dist/apr/apr-util-%{version}.tar.bz2
Patch1:         apr-util-1.4.1-testmemcache-initialize-values-array.patch
Patch2:         apr-util-visibility.patch
# PATCH-FIX-OPENSUSE apr-util-mariadb-10.2.patch dimstar@opensuse.org -- Fix build with mariadb 10.2
Patch3:         apr-util-mariadb-10.2.patch
BuildRequires:  apr-devel
BuildRequires:  autoconf
BuildRequires:  db-devel
BuildRequires:  doxygen
BuildRequires:  libexpat-devel
BuildRequires:  libtool
BuildRequires:  libuuid-devel
BuildRequires:  mysql-devel
BuildRequires:  openldap2-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  postgresql-devel >= 9.1.0
BuildRequires:  sqlite-devel
%requires_ge    libapr1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A companion library to APR, the Apache Portable Runtime.

%package -n %{libname}
Summary:        Apache Portable Runtime (APR) Utility Library
License:        Apache-2.0
Group:          System/Libraries
%requires_ge    libapr1

%description -n %{libname}
A companion library to APR, the Apache Portable Runtime.

%package devel
Summary:        Development files for the Apache Portable Runtime (APR) Utility Library
# apu-config returns -lldap -lber -ldb-<dbversion> -lexpat
# until this is fixed the devel package should require those
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Provides:       %{libname}-devel = %{version}
Obsoletes:      %{libname}-devel < %{version}-%{release}
Requires:       %{libname} = %{version}
Requires:       apr-devel
Requires:       db-devel
Requires:       libexpat-devel
Requires:       openldap2-devel

%description devel
This subpackage contains header files for developing applications
that want to make use of the APR Utility library.

%package -n %{libname}-dbd-mysql
Summary:        DBD driver for MySQL
License:        LGPL-2.1+
Group:          System/Libraries
Requires:       %{libname} = %{version}

%description -n %{libname}-dbd-mysql
DBD driver for MySQL database.

%package -n %{libname}-dbd-pgsql
Summary:        DBD driver for PostgreSQL
License:        Apache-2.0
Group:          System/Libraries
Requires:       %{libname} = %{version}

%description -n %{libname}-dbd-pgsql
DBD driver for PostgreSQL database.

%package -n %{libname}-dbd-sqlite3
Summary:        DBD driver for SQLite 3
License:        Apache-2.0
Group:          System/Libraries
Requires:       %{libname} = %{version}

%description -n %{libname}-dbd-sqlite3
DBD driver for SQLite 3 database.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
echo 'HTML_TIMESTAMP=NO' >> docs/doxygen.conf
export ac_cv_ldap_set_rebind_proc_style=three
rm -rf aclocal.m4 autom4te*.cache
autoreconf -fiv
sed -i -e '/OBJECTS_all/s, dbd/apr_dbd_[^ ]*\.lo,,g' build-outputs.mk
# all DBD driveres are built by default, nowadays -- except mysql
%configure \
    --includedir=%{includedir} \
    --with-crypto \
    --with-openssl=%{_prefix} \
    --with-apr=%{_bindir}/apr-1-config \
    --with-expat=%{_prefix} \
    --with-ldap \
    --with-berkeley-db \
    --with-mysql \
    --without-gdbm
make %{?_smp_mflags} CFLAGS="%{optflags} -DOPENSSL_LOAD_CONF -fvisibility=hidden"
make %{?_smp_mflags} dox

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
mv docs/dox/html html
# multiacrh anti-borker
perl -pi -e "s|^LDFLAGS=.*|LDFLAGS=\"\"|g" %{buildroot}%{_bindir}/apu-%{apuver}-config
# includes anti-borker
perl -pi -e "s|-I%{_includedir}/mysql||g" %{buildroot}%{_bindir}/apu-%{apuver}-config
# unpackaged files
rm -f %{buildroot}/%{_libdir}/aprutil.exp

find %{buildroot} -type f -name "*.la" -print -delete

%check
# fails on qemu, works on real hardware
%if !0%{?qemu_user_space_build:1}
# We are not thread safe in tests
make -j1 check
%endif

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc CHANGES
%doc LICENSE
%doc NOTICE
%{_libdir}/libaprutil-%{apuver}.so.*
%dir %{dso_libdir}
%{dso_libdir}/apr_ldap*
%{dso_libdir}/apr_dbm_db*
%{dso_libdir}/apr_crypto_openssl*

%files -n %{libname}-dbd-mysql
%defattr(-,root,root,-)
%{dso_libdir}/apr_dbd_mysql*

%files -n %{libname}-dbd-pgsql
%defattr(-,root,root,-)
%{dso_libdir}/apr_dbd_pgsql*

%files -n %{libname}-dbd-sqlite3
%defattr(-,root,root,-)
%{dso_libdir}/apr_dbd_sqlite3*

%files devel
%defattr(-,root,root)
%doc html
%dir %{includedir}
%{includedir}/*.h
%{_libdir}/libaprutil-%{apuver}.so
%{_bindir}/apu-%{apuver}-config
%{_libdir}/pkgconfig/apr-util-%{apuver}.pc

%changelog
* Tue Jun 12 2018 pgajdos@suse.com
- extend apr-util-mariadb-10.2.patch: Fix detection / build with
  MariaDB 10.2. [bsc#1094754]
* Wed Nov 22 2017 dimstar@opensuse.org
- Add apr-util-mariadb-10.2.patch: Fix detection / build with
  MariaDB 10.2.
* Tue Nov  7 2017 kstreitova@suse.com
- APR-util 1.6.1
  * apr_crypto: Fix compatibility with LibreSSL. PR 61596.
  * sdbm: better database/page validation to fail cleanly when
    corrupted [bsc#1064990], CVE-2017-12618
* Tue Oct 17 2017 mpluskal@suse.com
- We need to obsolete same version of package (bsc#1063305)
* Mon Jul 17 2017 jengelh@inai.de
- Replace unusual *.?a match by *.la.
- Fix RPM groups, diversify summaries.
* Wed Jul 12 2017 mpluskal@suse.com
- Rename package to apr-util
- Drop baselib.conf as it does not target any supported
  architecture
* Mon Jun 19 2017 crrodriguez@opensuse.org
- APR-util 1.6.0
  * Update MySQL build to stop using libmysqlclient_r
  * apr_siphash: Implement keyed hash function SipHash
  * apr_buckets: Add apr_bucket_file_set_buf_size()
  * apr_crypto: avoid excessive iteration in bcrypt hash.
  * apr_xml_to_text: Add style APR_XML_X2T_PARSED.
  * see http://www.apache.org/dist/apr/CHANGES-APR-UTIL-1.6 for
  extra details
* Thu Apr  7 2016 pgajdos@suse.com
- require just posgresql-devel everywhere, it seems to work now
* Thu Feb  4 2016 pgajdos@suse.com
- require postgresql-devel less then 9.4 to fix build on SLE_12
  and SLE_12_SP1
* Tue Oct 13 2015 pgajdos@suse.com
- require postgresql-devel version at least 9.1.0 to fix build for
  SLE-11-SP4
* Sat Oct 18 2014 coolo@suse.com
- fix requires after spec-cleaner
* Thu Oct 16 2014 tchvatal@suse.com
- Clean up with spec-cleaner
- Kill support of sle10 and sle9
- Remove unused configure switches
* Wed Sep 17 2014 crrodriguez@opensuse.org
- version 1.5.4
  * MySQL driver: Fix incorrect handling of bad parameter.
  * apr_crypto_get_driver(): Fix invalid storage reference on error path.
- docs: Tell doxygen not to store timestamps in files.
* Thu Nov 21 2013 crrodriguez@opensuse.org
- version 1.5.3
  * Add support to apr_memcache for unix domain sockets.
  * Add support for Berkeley DB 6.0.
* Wed Aug 28 2013 crrodriguez@opensuse.org
- Use compiler symbol visibility
- libapr1 does not have symbol *versioning* so requires_ge it
* Mon Jul 22 2013 crrodriguez@opensuse.org
- Update to apr-util 1.5.2
  * apr_uri_parse(): Do not accept invalid characters in the scheme.
  * Fix memory leak in hook sorting function.
  * Fix password validation failure for all crypt and crypt_r based
  * Fix potential data corruption in apr_brigade_write()
  * Fixes for ap_crypto,memcache etc.. see
  https://www.apache.org/dist/apr/CHANGES-APR-UTIL-1.5
* Tue Jul 16 2013 mls@suse.de
- get rid of --parents in doc section
* Fri Aug 17 2012 crrodriguez@opensuse.org
- Needs libuud-devel now
* Wed Aug  1 2012 crrodriguez@opensuse.org
- Apache 2.4.x complains "Your APR does not include SSL/EVP support."
  Indeed, that's the case, fix it.
* Sat Feb 18 2012 poeml@cmdline.net
- updated to 1.4.1
- fixed crash in memtest testcase. Patch sent upstreams
  https://issues.apache.org/bugzilla/show_bug.cgi?id=52705
  apr-util-1.4.1-testmemcache-initialize-values-array.patch
- removed obsolete libapr-util1-1.3.12-gcc46.patch
- Changes with 1.4.1:
  * ) Apply Windows build fixes for the apr_crypto API.
  Changes with 1.4.0:
  * ) apr_ldap_init: Pass secure=1 to ldapssl_init() with Solaris LDAP SDK.  PR: 42682
  * ) apr_memcache_server_create: Fix possible segfault. PR 51064.
  * ) apr_thread_pool: Fix thread unsafe pool usage.
  * ) Do not include apr.h and apr_errno.h from system search path in
    apu_errno.h. PR 46487
  * ) Add optional dbm, openssl and nss subpackages to the RPM spec file.
  * ) apr_dbd_freetds: The sybdb.h header file might be freetds/sybdb.h
    or sybdb.h.
  * ) Add apr_crypto implementations for OpenSSL and Mozilla NSS. Add a unit
    test to verify the interoperability of the two modules. Builds default
    to disabled unless explicitly enabled.
  * ) Add the apr_crypto interface, a rewrite of the earlier apr_ssl code,
    based on the modular dso interface used for dbd and ldap. Initially,
    the interface supports symmetrical encryption and decryption. The
    purpose of the interface is to offer portable and interoperable
    access to basic crypto using the native crypto libraries present on
    each platform.
  * ) Add trace probes to hooks, making it easier to inspect APR Hook based
    applications with DTrace or other such mechanisms.
  * ) Implement resource list when threads are unavailable. PR 24325
  Changes with 1.3.13:
  * ) Fix a failure of configure to detect ldap_set_rebind_proc(),
    encountered on Fedora 15 with gcc 4.6.
  * ) apr_thread_pool: Fix thread unsafe pool usage.
  * ) Improve platform detection for bundled expat by updating
    config.guess and config.sub.
  * ) Sync libtool handling of bundled expat from APR.
* Fri Jan 20 2012 draht@suse.de
- add Group tag to subpackages
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Mon Oct 17 2011 dmueller@suse.de
- disable testsuite on qemu builds
* Wed Oct 12 2011 dmueller@suse.de
- fix build on Factory
* Thu Sep 15 2011 draht@suse.de
- set -DLDAP_SET_REBIND_PROC_THREE for callback setting in Factory.
* Thu Sep  1 2011 draht@suse.de
- disable the (void)tmp; cast from %%patch1.
* Thu May 26 2011 crrodriguez@opensuse.org
- Update to 1.3.12, single bugfix release
  * ) apr_ldap: Fix crash because of NULL cleanup registered by
  apr_ldap_rebind_init().  [Rainer Jung]
* Fri May 20 2011 crrodriguez@opensuse.org
- run make check
- fix pkgconfig build requires for auto dependencies
* Fri May 20 2011 crrodriguez@opensuse.org
- Update to aprutil 1.3.11
  * SECURITY: CVE-2010-1623 (cve.mitre.org)
  * SECURITY: CVE-2009-3560, CVE-2009-3720 (cve.mitre.org)
  * apr_thread_pool: Fix some potential deadlock situations.  PR 49709.
  * apr_thread_pool_create: Fix pool corruption caused by multithreaded
  use of the pool when multiple initial threads are created.
* Wed May 18 2011 cfarrell@novell.com
- license update: Apache-2.0
  Updating to spdx.org syntax
* Thu Apr 28 2011 idoenmez@novell.com
- Add libapr-util1-1.3.9-gcc46.patch: fix ldap_set_rebind_proc
  detection with gcc 4.6
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs for SPARC
- add baselibs.conf as a source
* Mon Aug 10 2009 poeml@suse.de
- update to 1.3.9:
  * ) SECURITY: CVE-2009-2412 (cve.mitre.org)
    Fix overflow in rmm, where size alignment was taking place.
  * ) Make sure that "make check" is used in the RPM spec file, so that
    the crypto, dbd and dbm tests pass.
  * ) Make sure the mysql version of dbd_mysql_get_entry() respects the
    rule that if the column number exceeds the number of columns, we
    return NULL.
  * ) Ensure the dbm module is packaged up correctly in the RPM.
  * ) Clarify the error messages within the dbd tests.
* Wed Jul  8 2009 poeml@suse.de
- update to 1.3.8:
  * ) Use locally scoped variables in PostgreSQL driver to avoid stomping
    on return codes. PR 47431
  * ) Fix race conditions in initialisation of DBD, DBM and DSO.
  * ) Expose DBM libs in apu-1-config by default. To avoid that, use
    apu-1-config --avoid-dbm --libs. To get just DBM libs, use
    apu-1-config --dbm-libs.
  * ) Make sure --without-ldap works.
* Mon Jun  8 2009 poeml@suse.de
- update to 1.3.7
  * ) SECURITY:
    Fix a denial of service attack against the apr_xml_* interface
    using the "billion laughs" entity expansion technique.
  * ) Minor build and bug fixes.
  * ) SECURITY: CVE-2009-0023 (cve.mitre.org)
    Fix underflow in apr_strmatch_precompile.
  * ) Fix off by one overflow in apr_brigade_vprintf.
  * ) APR_LDAP_SIZELIMIT should prefer LDAP_DEFAULT_LIMIT/-1 when the
    SDK supports it, but in the absence of LDAP_DEFAULT_LIMIT (and
    LDAP_NO_LIMIT/0) it is not safe to use a literal -1.
  * ) Clean up ODBC types. Warnings seen when compiling packages for
    Fedora 11.
  * ) Use of my_init() requires my_global.h and my_sys.h.
  * ) Fix apr_memcache_multgetp memory corruption and incorrect error
    handling.
  * ) Fix memcache memory leak with persistent connections.
  * ) Add Oracle 11 support.
  * ) apr_dbd_freetds: Avoid segfault when process is NULL.
    Do no print diagnostics to stderr. Never allow driver to exit
    process.
  * ) apr_dbd_freetds: The sybdb.h header file might be freetds/sybdb.h
    or sybdb.h.
  * ) LDAP detection improvements: --with-ldap now supports library names
    containing non-alphanumeric characters, such as libldap-2.4.so.  New
    option --with-lber can be used to override the default liblber name.
    Fix a problem reporting the lber library from apu-N-config.
  * ) Suppress pgsql column-out-of-range warning.
  * ) Fix a buffer overrun and password matching for SHA passwords.
  * ) Introduce DSO handling of the db, gdbm and ndbm drivers, so these are
    loaded as .so's on first demand, unless --disable-util-dso is configured.
  * ) Fix a segfault in the DBD testcase when the DBD modules were not present.
- package %%{dso_libdir}/apr_dbm_db*
* Mon Mar  9 2009 poeml@suse.de
- enable build on CentOS5 and RHEL5
* Tue Nov 11 2008 ro@suse.de
- SLE-11 uses PPC64 instead of PPC, adapt baselibs.conf
* Thu Oct 30 2008 skh@suse.de
- obsolete old -XXbit packages (bnc#437293) (olh@suse.de)
* Tue Aug 19 2008 poeml@suse.de
- update to 1.3.4 final
  (updating to the release tarball, which has all the patches.)
* Fri Aug 15 2008 poeml@suse.de
- remove the incremental patches
    apr-util-1.3.2-r672712-pg-counting.patch
    apr-util-1.3.2-r673300-pgconfig.patch
    apr-util-1.3.2-r676473-reslist-doc.patch
    apr-util-1.3.2-r676801-mutex-destroy.patch
    apr-util-1.3.2-r679235-mysql-reconnect.patch
    apr-util-1.3.2-r679638-memcache-rusage.patch
    apr-util-1.3.2-r680529-reslist-limits.patch
  since they are included in apr-util-1.3.3.patch
* Fri Aug 15 2008 poeml@suse.de
- add apr-1.3.2-r685262.patch to memcache client
  * Fix a memory leak introduced in r683756 and a free call to a
    non malloced pointer in the case that the platform has no threads.
* Fri Aug  8 2008 poeml@suse.de
- the libapr_memcache0 package can be considered obsolete now,
  since apr 1.3.x has apr_memcache integrated; I removed it and
  added an Obsoletes tag here.
* Thu Aug  7 2008 poeml@suse.de
- add pre-1.3.3 patch with all other backports, in preparation to
  1.3.3 release. Plus latest version of 1.3.x non-pre_cleanup patch
  (apu-memcache_leak.patch)
* Thu Aug  7 2008 poeml@suse.de
- add post-1.3.2 patches (backports from trunk committed to the
  1.3.x branch)
    apr-util-1.3.2-r672712-pg-counting.patch
    apr-util-1.3.2-r673299-pgconfig.patch
    apr-util-1.3.2-r676473-reslist-doc.patch
    apr-util-1.3.2-r676801-mutex-destroy.patch
    apr-util-1.3.2-r679235-mysql-reconnect.patch
    apr-util-1.3.2-r679638-memcache-rusage.patch
    apr-util-1.3.2-r680529-reslist-limits.patch
    [#] to be discussed - but seems to work
    apr-util-trunk-r678323-memcache-memleak.patch
- drop obsolete workaround about pg_config
* Thu Aug  7 2008 poeml@suse.de
- update to 1.3.2
  * ) Fix parameter parsing error in ODBC DBD driver.  [Tom Donovan]
  * ) Older OpenLDAP implementations may have ldap_set_rebind_proc() with two
    args. Provide detection code and alternative implementation.
    [Ruediger Pluem]
  * ) Use pool memory when setting DBD driver name into the hash.
    [Bojan Smojver]
  * ) Add ODBC DBD Driver.  [Tom Donovan]
  * ) Fix build of the FreeTDS and MySQL drivers.  [Bojan Smojver]
  * ) Fix build failure for no modules (--disable-dso).  [Jean-Frederic Clere]
  * ) Fix win32 build failure for no modules (empty DBD_LIST).  [William Rowe]
* Thu Jul 17 2008 poeml@suse.de
- add /usr/lib/apr-util-1 directory to RPM filelist.
* Mon Jun 16 2008 poeml@suse.de
- pg_config is evil. Make sure it is not used to find PostgreSQL
  header files. Fixing build of of the PostgreSQL DBD adapter
  onopenSUSE 11.0.
* Sun Jun 15 2008 poeml@suse.de
- update to 1.3.0
  * ) apr_reslist: destroy all resources in apr_cleanup (don't give up on error).
    PR 45086 [Nick Kew]
  * ) Add apr_brigade_split_ex for reusing existing brigades in situation where
    brigades need to be split often during the lifetime of a pool.
    [Ruediger Pluem]
  * ) Amend apr_reslist to expire resources whose idle time exceeds ttl.
    PR 42841 [Tom Donovan, Nick Kew, Ruediger Pluem]
  * ) Modularize ldap's stub with the dbd dso modular structure, and teach
    the apu dso's to respect the system specific shared lib path var.
    To link to an application without ldap libs, query
    `apu-1-config --avoid-ldap --libs` (in addition to the usual linker
    queries for compiling and linking).  [William Rowe]
  * ) Support building DBD drivers as DSOs by default; use --disable-util-dso
    flag to configure to use static link.  [Joe Orton, Bojan Smojver]
  * ) All DBD drivers now count rows from 1, which affects PostgreSQL and MySQL
    drivers in particular. Using row number zero is an error.
    [Bojan Smojver]
  * ) Add support for OpenLDAP's ability to support a directory of
    certificate authorities. [Eric Covener]
  * ) Better error detection for bucket allocation failures.
    [Jim Jagielski]
  * ) Ensure that the LDAP code can compile cleanly on platforms that do
    not define the LDAP_OPT_REFHOPLIMIT symbol, most specifically Windows.
    [Victor <victorjss@gmail.com>, Graham Leggett]
  * ) Fix the setting of LDAP_OPT_SSL on Win2k, which expects a pointer to
    the value LDAP_OPT_ON, and not the value itself. XP works with both.
    [Victor <victorjss@gmail.com>]
  * ) Fix a regression in apr_brigade_partition that causes integer overflows
    on systems where apr_off_t > apr_size_t.  [Ruediger Pluem]
  * ) Ensure that apr_uri_unparse does not add scheme to URI if
    APR_URI_UNP_OMITSITEPART flag is set. PR 44044
    [Michael Clark <michael metaparadigm.com>]
  * ) Add an LDAP rebind implementation so that authentication can be
    carried through referrals. [Paul J. Reder]
  * ) Fix the make test target in the spec file. [Graham Leggett]
  * ) Introduce apr_dbd_open_ex() [Bojan Smojver]
  * ) Make md5 hash files portable between EBCDIC and ASCII platforms
    [David Jones]
  * ) Add limited apr_dbd_freetds driver (MSSQL and Sybase) [Nick Kew]
  * ) Commit relicensed apr_dbd_mysql driver to /trunk/  [Nick Kew]
  * ) Support BerkeleyDB 4.6.  [Arfrever Frehtes Taifersar Arahesis]
  * ) Support Tivoli ITDS LDAP client library.  [Paul Reder]
  * ) Portably implement testdate's long-time constants to solve
    compilation faults where #LL isn't valid.  [Curt Arnold]
  * ) Use buffered I/O with SDBM.  [Joe Schaefer]
  * ) Unify parsing of prepared statements and add binary argument functions
    to DBD [Bojan Smojver with help from many on the APR list]
  * ) Rewrite detection of expat in configure to fix build on e.g. biarch
    Linux platforms.  PR 28205.  [Joe Orton]
  * ) Add apr_thread_pool implementation.  [Henry Jen <henryjen ztune.net>]
  * ) Add support for Berkeley DB 4.5 to the configure scripts.
    [Garrett Rooney]
  * ) Allow apr_queue.h to be included before other APR headers.
    PR 40891 [Henry Jen <henryjen ztune.net>]
  * ) Fix precedence problem in error checking for sdbm dbm back end.
    PR 40659 [Larry Cipriani <lvc lucent.com>]
  * ) Add an apr_reslist_acquired_count, for determining how many outstanding
    resources there are in a reslist.  [Ryan Phillips <ryan trolocsis.com>]
  * ) Provide folding in autogenerated .manifest files for Win32 builders
    using VisualStudio 2005  [William Rowe]
  * ) Implement DBD transaction modes
    [Bojan Smojver with help from many on the APR list]
  * ) Implement prepared statement support in SQLite3 DBD driver
    [Bojan Smojver]
  * ) Add get (column) name to apr_dbd API
    [Bojan Smojver <bojan rexursive.com>] and
    [Chris Darroch <chrisd pearsoncmg com>]
  * ) Make the DBD autoconf-glue use LDFLAGS instead of LIBS in several
    places, fixing some configure issues on Solaris.
    [Henry Jen <henryjen ztune.net>]
  * ) Make apr_dbd.h work as a stand alone header, without needing other
    files to be included before it. [Henry Jen <henryjen ztune.net>]
  * ) On platforms that use autoconf stop automatically linking against
    apr-iconv when an apr-iconv source dir is found in ../apr-iconv.
    Instead, add a --with-apr-iconv option to configure that lets you
    specify the relative path to your apr-iconv source directory.
    [Garrett Rooney]
  * ) APR_FIND_APU macro now supports customisable detailed checks on
    each installed apr-util. [Justin Erenkrantz, Colm MacCarthaigh]
  * ) APR_FIND_APU macro no longer checks /usr/local/apache2/
    [Colm MacCarthaigh]
  * ) Add apr_dbd_oracle driver [Nick Kew and Chris Darroch]
- remove obsolete patches:
  apr-util-1.2.12-ac_configure_args.patch
  apr-util-1.2.12-no_linkage.patch
  apr-util-1.2.12-dso.patch
  apr-util-1.2.12-link.patch
  apr-util-1.2.8-r521327.patch
  DSO build is now handled by the build system and it is also the
  default now.
- remove manual run of the testsuite, this has also been fixed
  upstreams.
- the DBD dsos now live in /usr/lib*/apr-util-1.
* Mon Jun  9 2008 poeml@suse.de
- build service supports the debuginfo flag in metadata now; remove
  debug_package macro from the specfile therefore.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Jan 23 2008 poeml@suse.de
- re-fix build of apr_dbd_mysql module on SLES_9 (must have been
  broken on Tue Aug 21 2007)
* Wed Jan 23 2008 poeml@suse.de
- fix DSO build so it doesn't incur linkage to the database libs,
  which happened since the 1.2.12, and which I hadn't time to fix
  yet. Patches from PLD and Oden Eriksson (Mandrake) very much
  appreciated.
    +Patch10:        apr-util-1.2.12-no_linkage.patch
    +Patch11:        apr-util-1.2.12-dso.patch
    +Patch12:        apr-util-1.2.12-link.patch
- another patch was rebased and renamed:
  - Patch:          apr-util-1.2.7.diff
    +Patch:          apr-util-1.2.12-ac_configure_args.patch
- build DSOs manually (by changing build-outputs.mk to not make
  dbd/apr_dbd_[^ ]*\.lo. Thereby avoiding database symbols in
  the resulting libaprutil-1 shared object
- fix up apu-1-config LDFLAGS and INCLUDES in the end
- update the run of testcases
- remove openldap2 from BuildRequires, because that part is the
  server component which is never needed for building.
- added requires for openldap2-devel db-devel to the devel
  package as apu-1-config returns the libs (change from Factory)
* Tue Nov 27 2007 poeml@suse.de
- update to 1.2.12:
  * ) Wakeup threads waiting for a reslist resource after a resource was
    invalidated. [Ruediger Pluem]
  * ) Fix GMT offset for several date formats and add a new format.
    [Maxime Petazzoni <maxime.petazzoni bulix.org>]
  * ) Numerous fixes to the test/ framework, including better handling of
    long size_t comparisons and more consistent Makefile.(in|win) setup
    for authoring new tests.  [William Rowe]
  * ) Win32 build fixes including a Makefile.win scheme, fixes for 64P
    model x86_64 compiles and VC8 builds.  [William Rowe]
  * ) Type mismatch between apr_datum_t and GDBM's datum type could
    yield a corrupt apr_datum_t when reading from a GDBM database.
    PR 43025.  [BjÃ¶rn Wiberg <Bjorn.Wiberg its.uu.se>, Davi Arnaut]
  * ) Add the #define APR_LDAP_SIZELIMIT that is set appropriately
    for the LDAP SDK that is being used. Also include ZOS as an
    LDAP Platform.
    PR 37814.  [David Jones <oscaremma gmail com>, Davi Arnaut]
  * ) Fix exported LDFLAGS with new expat detection.  PR 43337.
    [Justin Erenkrantz]
  * ) Add MySQL DBD driver [Nick Kew, Bojan Smojver]
- drop source file apr_dbd_mysql.c, which was distributed
  separately until now. Functional changes to the previous version
  are:
  * added mysql_thread_init() (see
    http://www.nabble.com/-PATCH--apr_dbd_mysql.c-t4314862.html)
  * allow groups=xyz in the DBDParams setting
- drop apr-util-1.2.8-dso.patch, apr-util-1.2.12-dbd.patch,
  apr-util-1.2.8_dbd_mysql_buildconf.patch
- adjust apr-util-1.2.8-dbd.patch
- fix empty rpm macro "helpdir", which lead to an error
* Wed Sep 12 2007 poeml@suse.de
- use debug_package macro only on suse, because it breaks the build
  on Mandriva
* Mon Sep 10 2007 poeml@suse.de
- update to 1.2.10:
  * ) Support BerkeleyDB 4.6.  [Arfrever Frehtes Taifersar Arahesis]
  * ) Test improvements to validate testmd4 and testdbm, unattended.
    [Bojan Smojver]
  * ) Ensure that an apr_reslist shrinks back to SMAX via the TTL by
    reorganising the resource list from a queue to a stack.
    PR 40348.  [Christian BOITEL <christian_boitel yahoo.fr>]
  * ) Fix Solaris 2.8+ fdatasync() detection. The fdatasync() function
    is marked as part of the Realtime library functions.
    PR 37343.  [Davi Arnaut]
  * ) Change configure's expat detection to use standard linker-based
    tests, fixing build on e.g. biarch Linux systems.  PR 28205.
    [Joe Orton, Ruediger Pluem]
  * ) Portably implement testdate's long-time constants to solve
    compilation faults where #LL isn't valid.  [Curt Arnold]
  * ) APR_FIND_APU macro no longer checks /usr/local/apache2/.
    PR 42089.  [Colm MacCÃ¡rthaigh]
  * ) Fix handling of attribute namespaces in apr_xml_to_text() when
    a namespace map is provided.  PR 41908.  [Joe Orton]
- update apr_dbd_mysql.c to r54
  - Rework for unified parsing of prepared statements
  - Add binary argument functions
  - Update Licensing
    http://bahumbug.wordpress.com/2007/01/09/re-licensing-apr_dbd_mysql/
* Mon Aug 27 2007 poeml@suse.de
- add apr-util-1.2.8-r521327.patch:
  dbd/apr_dbd.c (apr_dbd_get_driver): Ensure driver DSOs have the
  same lifetime as the hash table. Backport from trunk (r521327)
* Tue Aug 21 2007 crrodriguez@suse.de
- first attempt to remove static libraries and libtool crap
* Wed Jul 18 2007 poeml@suse.de
- fixed wrong rpm tag (Buildrequires -> Requires libexpat-devel)
* Wed Jul 18 2007 poeml@suse.de
- make last fix buildservice compatible
- add debug_package macro in buildservice (will soon be obsolete)
* Sat Apr 28 2007 aj@suse.de
- Add libexpat-devel to build requires.
* Wed Dec 20 2006 poeml@suse.de
- fix sqlite plugin building for sqlite2, it wasn't linked against
  the lib
- work around mysql plugin build on SLES9 with a kludge
  (libmysqlclient_r was missing the .so link at SLES9 time
* Thu Dec 14 2006 poeml@suse.de
- DSO-ify the build of dbd backends
* Thu Dec 14 2006 poeml@suse.de
- add sqlite and pgsql support, and rpm-macroize it
* Wed Dec 13 2006 mrueckert@suse.de
- added apr-util-1.2.8_dbd_mysql_buildconf.patch and
  http://apache.webthing.com/svn/apache/apr/apr_dbd_mysql.c:
  the patch and the additional .c file add mysql support to apr-dbd
* Mon Dec 11 2006 poeml@suse.de
- update to 1.2.8
  * ) Add support for Berkeley DB 4.5 to the configure scripts.
  * ) Allow apr_queue.h to be included before other APR headers.
  * ) Implement prepared statement support in SQLite3 DBD driver
  * ) Fix to ensure that "deprecated" LDAP interfaces are still
    exposed if using OpenLDAP 2.3.
  * ) Fix incorrect byte order and incorrect timestamp type
    in the fallback UUID generator used when no external UUID
    generator is detected by APR.
* Sat Oct 21 2006 olh@suse.de
- libexpat.la was removed, look for libexpat.a also in lib64 (214240)
  build parallel
* Mon Sep 18 2006 poeml@suse.de
- fix Buildrequires on FC and Mandriva
* Thu Jun 22 2006 schwab@suse.de
- Don't depend on configure args being preserved.
* Tue May 30 2006 poeml@suse.de
- fix BuildRequires for Fedora Core
- ditch krb5 from BuildRequires, since it doesn't seem to be needed
- use --with-berkeley-db
* Tue Apr 25 2006 poeml@suse.de
- upstream 1.2.7. relevant changes:
  * ) Fix apr_dbd_init to be safe to call multiple times
  * ) Stop trying to link against Berkeley DB by default.
    (use --with-berkeley-db)
  * ) Stop trying to link against GDBM by default. (use --with-gdbm)
  * ) Fix the escape implementations for the sqlite2 and sqlite3 dbd
    back ends.
  * ) Add support for Berkeley DB 4.4 to the configure scripts.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 12 2005 poeml@suse.de
- update to 1.2.2
* Thu Sep 29 2005 poeml@suse.de
- update to 1.2.1
- remove -DLDAP_DEPRECATED: all CFLAGS are derived from apr-config
* Sun Sep 25 2005 ro@suse.de
- added LDAP_DEPRECATED to CFLAGS
* Thu Mar 24 2005 poeml@suse.de
- update to 1.1.2
* Fri Feb 25 2005 poeml@suse.de
- package created (1.1.0)
